@@ -33,21 +33,18 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
+#include <camel/camel.h>
 #include <libedataserver/e-source.h>
 #include <libedataserver/e-source-list.h>
 #include <libedataserver/e-source-group.h>
 #include <libedataserver/e-xml-utils.h>
 #include <libedataserver/e-xml-hash-utils.h>
 
-#include <camel/camel-url.h>
-
 #include <e2k-marshal.h>
 #include <e2k-uri.h>
 #include <exchange-account.h>
 #include <e-folder-exchange.h>
 
-#include <e-util/e-dialog-utils.h>
-
 #include "exchange-share-config-listener.h"
 
 struct _ExchangeShareConfigListenerPrivate {
@@ -71,7 +68,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint signals [LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
 
 #define PARENT_TYPE E_TYPE_ACCOUNT_LIST
 
